==> todotask2.0.2.zip: todotask2/app/views/user/login.php <==
<?php
	// ページ描画
	// ヘッダ
	require_once(TODOTASK_VIEW_DIR.'/common/header.inc.php');

?>

<div align="center">
<form action="<?php echo ROOT_URL; ?>userlogin.php" method="post" name="myForm">
<big><?php echo $this->art_msg; ?></big><br><br>

<table border="0" bordercolor="#BBBBFF" cellspacing="0" width="400" class="frminput">
<tr>
	<td width="180">
		ID
	</td>
	<td width="220">
		<input type="text" name="id" value="<?php echo $this->user_id; ?>" style="width:100%;" maxlength="32"><BR>
	</td>
</tr>
<tr>
	<td>
		パスワード
	</td>
	<td>
		<input type="password" name="pass" value="<?php echo $this->pass; ?>" style="width:100%;" maxlength="64"><BR>
	</td>
</tr>
</table>
<label for="loginchk">
<input name="staylogin" type="checkbox" value="1" id="loginchk">ログイン状態を保存する</label><br>

<input type="submit" class="submit" value="ログイン">
<input type="hidden" name="csrf" value="<?php echo $this->csrf; ?>">
</form>


<div class="noticediv">
<big>外部認証をつかってログインできます！<br></big>
<small>
※下記サービスに対応していますサービスの画像をクリックでログインできます。<br>
※外部認証でログインした場合はメール等の一部機能がつかえなくなります。<br>
※認証が正常にできた場合、各サービスid(hatena_***)がついた形でユーザー作成されます。<br>
※外部認証を利用される方は<a href="<?php echo INFO_TERMOFUSE_PAGE; ?>">利用規約</a>への同意が必要となります。<br>
</small>

<hr size="1">

<?php
if (HATENA_AUTHFLG) {
?>
<div style="text-align:left;">
<a href="<?php echo $this->hatenaloginurl; ?>">
<img src="http://www.hatena.ne.jp/images/top/h1.gif" border="0" align="left">
<br>
はてな認証を利用してログインする<br /></a>
<small>
<a href="http://auth.hatena.ne.jp/" target="_blank">はてな認証APIについてはこちら</a>
</small>
</div>
<br><br>
<?php
}
?>

<?php
if (JUGEM_AUTHFLG) {
?>
<div style="text-align:left;">
<a href="<?php echo $this->jyugemuloginurl; ?>">
<img src="http://jugemkey.jp/img/admin/menu/logo_admin.gif" border="0" align="left">
<br />
ジュゲム認証を利用してログインする<br /></a>
<small>
<a href="http://jugemkey.jp/" target="_blank">JugemKey認証APIについてはこちら</a>
</small>
</div>
<br><br>
<?php
}
?>


<?php
if (LIVEDOOR_AUTHFLG) {
?>
<div style="text-align:left;">
<a href="<?php echo $this->livedoorloginurl; ?>" target="_blank">
<img src="http://auth.livedoor.com/img/cmn/head_livedoor.gif" border="0" align="left"><img src="http://auth.livedoor.com/img/cmn/head_logo.gif" border="0" align="left">
<br />
ライブドア認証を利用してログインする<br /></a>
<small>
<a href="http://auth.livedoor.com/" target="_blank">ライブドア認証APIについてはこちら</a>
</small>
</div>
<?php
}
?>



<br><br>

</div>

<br><br>

<div class="noticediv">
やらなきゃいけない事は覚えてたんだけど、<br>
<a href="<?php echo ROOT_URL; ?>userreminder.php">登録したID/PASSを忘れちゃった！というかたはこちら</a>から、<br>
ログイン情報の再取得ができます。
</div>


<br><big>
<a href="<?php echo ROOT_URL . $this->backurl; ?>">もどる</a></big>

</div>

<code>
<script type="text/javascript" Language="JavaScript">

	if (document.myForm.id.value == "") {
		var oid = new inputDefault(document.myForm.id, 'IDを入力してください。');
		oid.set();
	}
	if (document.myForm.pass.value == "") {
		var opass = new inputDefault(document.myForm.pass, '');
		opass.set();
	}

</script>
</code>

<?php
	// フッター
	include_once(TODOTASK_VIEW_DIR.'/common/footer.inc.php');
?>

==> todotask2.1.2.zip: todotask2/app/views/user/login.php <==
<?php
	// ページ描画
	// ヘッダ
	require_once(TODOTASK_VIEW_DIR.'/common/header.inc.php');
?>

<div align="center">
<form action="userlogin.php?group_no=<?php echo $this->group_no; ?>" method="post" name="myForm">
<big><?php echo $this->art_msg; ?></big><br><br>

<table border="0" bordercolor="#BBBBFF" cellspacing="0" width="400" class="frminput">
<tr>
	<td width="180">
		ID
	</td>
	<td width="220">
		<input type="text" name="id" value="<?php echo $this->user_id; ?>" style="width:100%;" maxlength="32"><BR>
	</td>
</tr>
<tr>
	<td>
		パスワード
	</td>
	<td>
		<input type="password" name="pass" value="<?php echo $this->pass; ?>" style="width:100%;" maxlength="64"><BR>
	</td>
</tr>
</table>
<label for="loginchk">
<input name="staylogin" type="checkbox" value="1" id="loginchk">ログイン状態を保存する</label><br>

<input type="submit" class="submit" value="ログイン">
<input type="hidden" name="csrf" value="<?php echo $this->csrf; ?>">
<?php
if (SSL_ROOT_URL != "" && !ACTIVE_SSL) {

?>
<br>
<a href="<?php echo SSL_ROOT_URL."userlogin.php?group_no=".$this->group_no; ?>">SSL 128ビット暗号化モードでログイン画面をご利用されたい方はこちら</a>


<?php
}
?>


</form>





<div class="noticediv">
<big>外部認証をつかってログインできます！<br></big>
<small>
※下記サービスに対応していますサービスの画像をクリックでログインできます。<br>
※外部認証でログインした場合はメール等の一部機能がつかえなくなります。<br>
※認証が正常にできた場合、各サービスid(hatena_***)がついた形でユーザー作成されます。<br>
※外部認証を利用される方は<a href="<?php echo INFO_TERMOFUSE_PAGE; ?>">利用規約</a>への同意が必要となります。<br>
</small>

<hr size="1">

<?php
if (HATENA_AUTHFLG) {
?>
<div style="text-align:left;">
<a href="<?php echo $this->hatenaloginurl; ?>">
<img src="http://www.hatena.ne.jp/images/top/h1.gif" border="0" align="left">
<br>
はてな認証を利用してログインする<br /></a>
<small>
<a href="http://auth.hatena.ne.jp/" target="_blank">はてな認証APIについてはこちら</a>
</small>
</div>
<br><br>
<?php
}
?>

<?php
if (JUGEM_AUTHFLG) {
?>
<div style="text-align:left;">
<a href="<?php echo $this->jyugemuloginurl; ?>">
<img src="http://jugemkey.jp/img/admin/menu/logo_admin.gif" border="0" align="left">
<br />
ジュゲム認証を利用してログインする<br /></a>
<small>
<a href="http://jugemkey.jp/" target="_blank">JugemKey認証APIについてはこちら</a>
</small>
</div>
<br><br>
<?php
}
?>


<?php
if (LIVEDOOR_AUTHFLG) {
?>
<div style="text-align:left;">
<a href="<?php echo $this->livedoorloginurl; ?>" target="_blank">
<img src="http://auth.livedoor.com/img/cmn/head_livedoor.gif" border="0" align="left"><img src="http://auth.livedoor.com/img/cmn/head_logo.gif" border="0" align="left">
<br />
ライブドア認証を利用してログインする<br /></a>
<small>
<a href="http://auth.livedoor.com/" target="_blank">ライブドア認証APIについてはこちら</a>
</small>
</div>
<?php
}
?>



<br><br>

</div>

<br><br>

<div class="noticediv">
やらなきゃいけない事は覚えてたんだけど、<br>
<a href="<?php echo ROOT_URL; ?>userreminder.php">登録したID/PASSを忘れちゃった！というかたはこちら</a>から、<br>
ログイン情報の再取得ができます。
</div>


<br><big>
<a href="<?php echo ROOT_URL . $this->backurl; ?>">もどる</a></big>

</div>

<code>
<script type="text/javascript" Language="JavaScript">

	if (document.myForm.id.value == "") {
		var oid = new inputDefault(document.myForm.id, 'IDを入力してください。');
		oid.set();
	}
	if (document.myForm.pass.value == "") {
		var opass = new inputDefault(document.myForm.pass, '');
		opass.set();
	}

</script>
</code>

<?php
	// フッター
	include_once(TODOTASK_VIEW_DIR.'/common/footer.inc.php');
?>
